Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(313)

Unified Diff: webkit/fileapi/file_system_mount_point_provider.h

Issue 6749021: Added new fileBrowserPrivate and fileHandler extension APIs (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/fileapi/file_system_mount_point_provider.h
===================================================================
--- webkit/fileapi/file_system_mount_point_provider.h (revision 80624)
+++ webkit/fileapi/file_system_mount_point_provider.h (working copy)
@@ -5,6 +5,8 @@
#ifndef WEBKIT_FILEAPI_FILE_SYSTEM_MOUNT_POINT_PROVIDER_H_
#define WEBKIT_FILEAPI_FILE_SYSTEM_MOUNT_POINT_PROVIDER_H_
+#include <vector>
+
#include "base/file_path.h"
#include "googleurl/src/gurl.h"
#include "webkit/fileapi/file_system_path_manager.h"
@@ -18,9 +20,14 @@
public:
virtual ~FileSystemMountPointProvider() {}
- // Checks if mount point access is allowed from |origin_url|.
- virtual bool IsAccessAllowed(const GURL& origin_url) = 0;
+ // Checks if access to |virtual_path| is allowed from |origin_url|.
+ virtual bool IsAccessAllowed(const GURL& origin_url,
+ const FilePath& virtual_path) = 0;
+ // Checks if access to |virtual_path| is allowed from |origin_url|.
ericu 2011/04/08 02:12:14 Copy/paste of comment.
zel 2011/04/08 04:16:36 Done.
+ virtual void GrantAccess(const GURL& origin_url,
+ const FilePath& virtual_path) = 0;
+
// Retrieves the root path for the given |origin_url| and |type|, and
// calls the given |callback| with the root path and name.
// If |create| is true this also creates the directory if it doesn't exist.
@@ -41,6 +48,11 @@
// Checks if a given |name| contains any restricted names/chars in it.
// Callable on any thread.
virtual bool IsRestrictedFileName(const FilePath& filename) const = 0;
+
+ // Returns the list of top level directories that are exposed by this
+ // provider. This list is used to set appropriate child process file access
+ // permissions.
+ virtual std::vector<FilePath> GetRootDirectories() const = 0;
};
} // namespace fileapi

Powered by Google App Engine
This is Rietveld 408576698